@@ -309,6 +309,14 @@ class Datastore:
         instance._source = datastore.spec.source
         instance._s3_no_copy = instance._source == V1DatastoreSourceType.OBJECT_STORE_REFERENCE_ONLY
         instance._fsx_enabled = instance._source == V1DatastoreSourceType.FSX
+        if instance._fsx_enabled:
+            instance._fsx_throughput_mbs_tib = datastore.spec.fsx_spec.storage_throughput_mb_s_tib
+            instance._fsx_capacity_gib = datastore.spec.fsx_spec.storage_capacity_gib
+            instance._fsx_preloading = datastore.spec.fsx_spec.preload_data_on_create
+        else:
+            instance._fsx_throughput_mbs_tib = 0
+            instance._fsx_capacity_gib = 0
+            instance._fsx_preloading = False
         instance._status = datastore.status.phase
         instance._created_at = datastore.created_at
         instance._size = f"{datastore.spec.size_mib} MiB"
