@@ -112,6 +112,8 @@ def get_user_team_members() -> List[User]:
                     user_id=member_data['id'],
                     username=member_data['username'],
                     team_name=team_data['name'],
+                    first_name=member_data['firstName'],
+                    last_name=member_data['lastName']
                 )
             )
     return users
